@@ -3,19 +3,17 @@
 #' Compute Conditional Mutual Info between random variables 'v1' and 'v2'
 #' given random vector 'vcs'.
 #'
-#' @import stats
-#'
 #' @param v1 random variable 1
 #' @param v2 random variable 2
 #' @param vcs random vector 'vcs'
 #'
 #' @return Conditional Mutual info between 'v1' and 'v2'
-#' @examples
+# #' @examples
 #' computeCmi(c(3,5),c(3,5))
 #'
-#' @export
-computeCmi <- function(v1,v2,vcs)
-{
+#' @keywords internal
+#' @noRd
+computeCmi <- function(v1,v2,vcs) {
   if(nargs() == 2)
   {
     c1 <-  stats::var(v1)
